Crate git_sshripped_ssh_identity

Crate git_sshripped_ssh_identity 

Functions

agent_public_keys
Query the SSH agent for loaded public keys.
default_private_key_candidates
default_public_key_candidates
detect_identity
Auto-detect the best available SSH identity.
discover_ssh_key_files
Scan ~/.ssh/ for all files ending in .pub that have a corresponding private key file (same path without .pub). Returns (private, public) pairs.
identity_files_from_ssh_config
Parse ~/.ssh/config and extract all IdentityFile directive values. Expands leading ~ and ~/ to the user’s home directory.
private_keys_matching_agent
Find local private key files whose public keys are loaded in the SSH agent.
unwrap_repo_key_from_wrapped_files
Try each identity to decrypt a wrapped repo key file.
unwrap_repo_key_with_agent_helper
Unwrap a repo key using an external agent helper program.
well_known_public_key_paths
Returns only the well-known standard public key paths.