Functions
- agent_
public_ keys - Query the SSH agent for loaded public keys.
- default_
private_ key_ candidates - default_
public_ key_ candidates - detect_
identity - Auto-detect the best available SSH identity.
- discover_
ssh_ key_ files - Scan
~/.ssh/for all files ending in.pubthat have a corresponding private key file (same path without.pub). Returns(private, public)pairs. - identity_
files_ from_ ssh_ config - Parse
~/.ssh/configand extract allIdentityFiledirective values. Expands leading~and~/to the user’s home directory. - private_
keys_ matching_ agent - Find local private key files whose public keys are loaded in the SSH agent.
- unwrap_
repo_ key_ from_ wrapped_ files - Try each identity to decrypt a wrapped repo key file.
- unwrap_
repo_ key_ with_ agent_ helper - Unwrap a repo key using an external agent helper program.
- well_
known_ public_ key_ paths - Returns only the well-known standard public key paths.